#include "cardgame.h"

#include "pmode4game_private.h"


void enableInvertedColorText(BOOL enabled)
{
    colorInversionMask = (enabled ? 0xFF : 0x00);
}


void setColorInversionMask(byte newColorInversionMask)
{
    colorInversionMask = newColorInversionMask;
}
